@@ -14,20 +14,21 @@
 # under the License.
 [
   'external',
-  'internalapi',
+  'internal_api',
   'storage',
-  'storagemgmt',
+  'storage_mgmt',
   'tenant',
   'management',
+  'ctlplane',
 ].each do |network|
   Facter.add('fqdn_' + network) do
     setcode do
-      external_hostname_parts = [
+      hostname_parts = [
         Facter.value(:hostname),
-        network,
+        network.gsub('_', ''),
         Facter.value(:domain),
       ].reject { |part| part.nil? || part.empty? }
-      external_hostname_parts.join(".")
+      hostname_parts.join(".")
     end
   end
 end
