@@ -19,7 +19,7 @@ require 'spec_helper'
 describe 'tripleo::profile::base::aodh::api' do
   shared_examples_for 'tripleo::profile::base::aodh::api' do
     let(:pre_condition) do
-      "class { '::tripleo::profile::base::aodh': step => #{params[:step]}, rabbit_hosts => ['localhost.localdomain'] }"
+      "class { '::tripleo::profile::base::aodh': step => #{params[:step]}, oslomsg_rpc_hosts => ['localhost.localdomain'] }"
     end
 
     context 'with step less than 3' do
@@ -33,34 +33,11 @@ describe 'tripleo::profile::base::aodh::api' do
       end
     end
 
-    context 'with step 3 and not bootstrap' do
+    context 'with step 3' do
       let(:params) { {
         :step => 3,
       } }
 
-      it 'should trigger complete configuration' do
-        is_expected.not_to contain_class('aodh::api')
-        is_expected.not_to contain_class('aodh::wsgi::apache')
-      end
-    end
-
-    context 'with step 3 and bootstrap' do
-      let(:params) { {
-        :step           => 3,
-        :bootstrap_node => 'node.example.com'
-      } }
-
-      it 'should trigger complete configuration' do
-        is_expected.to contain_class('aodh::api')
-        is_expected.to contain_class('aodh::wsgi::apache')
-      end
-    end
-
-    context 'with step 4' do
-      let(:params) { {
-        :step => 4,
-      } }
-
       it 'should trigger complete configuration' do
         is_expected.to contain_class('aodh::api')
         is_expected.to contain_class('aodh::wsgi::apache')
